@@ -1,6 +1,6 @@
 from typing import TYPE_CHECKING
 
-# typing doesnt understand aenum so im pretending its stdlib enum while type checking
+# typing does not understand aenum so I am pretending its stdlib enum while type checking
 
 if TYPE_CHECKING:
     import enum
@@ -14,10 +14,11 @@ __all__ = (
     "RelationshipType",
     "AssetType",
     "SortType",
+    "EmbedType"
 )
 
 class ChannelType(enum.Enum):
-    saved_message = "SavedMessage"
+    saved_messages = "SavedMessages"
     direct_message = "DirectMessage"
     group = "Group"
     text_channel = "TextChannel"
@@ -49,3 +50,9 @@ class SortType(enum.Enum):
     latest = "Latest"
     oldest = "Oldest"
     relevance = "Relevance"
+
+class EmbedType(enum.Enum):
+    website = "Website"
+    image = "Image"
+    text = "Text"
+    none = "None"
